maite.testing.pyright.PyrightOutput
===================================

.. currentmodule:: maite.testing.pyright

.. autoclass:: PyrightOutput

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      
        ~PyrightOutput.version
      
      
        ~PyrightOutput.time
      
      
        ~PyrightOutput.generalDiagnostics
      
      
        ~PyrightOutput.summary
      
   
   